@@ -1,8 +1,9 @@
+import os
+
 from django import template
 
 register = template.Library()
 
-
 @register.filter
 def get_file_format (post, ftype):
   return post.mediafile_set.get(ext__ext=ftype)
@@ -10,4 +11,8 @@ def get_file_format (post, ftype):
 @register.filter
 def http_url (url):
   return url.replace('https://', 'http://')
+  
+@register.filter
+def filename (path):
+  return os.path.basename(path)
   
\ No newline at end of file
